@@ -4,7 +4,7 @@
 
 #define QT_FEATURE_pipewire_screencapture -1
 
-#define QT_FEATURE_alsa 1
+#define QT_FEATURE_alsa -1
 
 #define QT_FEATURE_avfoundation -1
 
@@ -12,17 +12,17 @@
 
 #define QT_FEATURE_videotoolbox -1
 
-#define QT_FEATURE_gstreamer 1
+#define QT_FEATURE_gstreamer -1
 
-#define QT_FEATURE_gstreamer_photography 1
+#define QT_FEATURE_gstreamer_photography -1
 
-#define QT_FEATURE_gstreamer_gl 1
+#define QT_FEATURE_gstreamer_gl -1
 
-#define QT_FEATURE_gstreamer_gl_wayland 1
+#define QT_FEATURE_gstreamer_gl_wayland -1
 
-#define QT_FEATURE_gstreamer_gl_egl 1
+#define QT_FEATURE_gstreamer_gl_egl -1
 
-#define QT_FEATURE_gstreamer_gl_x11 1
+#define QT_FEATURE_gstreamer_gl_x11 -1
 
 #define QT_FEATURE_gpu_vivante -1
 
@@ -30,13 +30,13 @@
 
 #define QT_FEATURE_linux_dmabuf 1
 
-#define QT_FEATURE_vaapi -1
+#define QT_FEATURE_vaapi 1
 
 #define QT_FEATURE_mmrenderer -1
 
 #define QT_FEATURE_native_android_backend -1
 
-#define QT_FEATURE_pulseaudio -1
+#define QT_FEATURE_pulseaudio 1
 
 #define QT_FEATURE_opensles -1
 
